#
# Copyright 2013 - Noorul Islam K M
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

import json

from solum_tempest_plugin import base


class TestSensorController(base.TestCase):

    def test_sensors_get_all(self):
        resp, body = self.client.get('v1/sensors')
        if isinstance(body, bytes):
            body = body.decode('utf-8')
        data = json.loads(body)
        self.assertEqual(200, resp.status)
        self.assertEqual([], data)
